/*
 * Copyright 2025 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

import QtQuick 2.15
import QtQuick.Layouts 1.15
import org.ukui.quick.items 1.0 as UkuiItems
import org.ukui.quick.platform 1.0

Column {
    id: configGroupView

    property alias groups: repeater.model
    property int itemHeight: 60
    property int itemCheckBoxHeight: 0
    property int itemLineEditHeight: 0
    property int itemSwitchHeight: 0
    property int itemSpacing: 2
    property bool autoSave: false
    property bool useCustomTranslate: false
    property bool enableBackground: true
    property bool groupTitlebold: true
    property var saveHandler: null
    property var openExternalHandler: null
    property int itemLayoutMargins: 0

    spacing: 40
    anchors.left: parent.left
    anchors.right: parent.right
    anchors.margins: 24

    Repeater {
        id: repeater

        delegate: Column {
            spacing: 2
            width: configGroupView.width

            UkuiItems.StyleText {
                visible: modelData.description !== ""
                text: modelData.description
                font.bold: groupTitlebold
                pointSizeOffset: groupTitlebold ? 2 : 0
                anchors.left: parent.left
                anchors.leftMargin: groupTitlebold ? 16 : 0
            }

            Rectangle {
                width: configGroupView.width
                height: childrenRect.height
                radius: 8
                color: "transparent"

                Column {
                    width: parent.width
                    spacing: configGroupView.itemSpacing
                    topPadding: 8
                    bottomPadding: 8

                    Repeater {
                        model: modelData.items

                        delegate: ConfigItemLoader {
                            itemWidth: configGroupView.width
                            itemHeight: configGroupView.itemHeight
                            itemCheckBoxHeight: configGroupView.itemCheckBoxHeight
                            itemLineEditHeight: configGroupView.itemLineEditHeight
                            itemLayoutMargins: configGroupView.itemLayoutMargins
                            itemSwitchHeight: configGroupView.itemSwitchHeight
                            anchors.horizontalCenter: parent.horizontalCenter
                            enableBackground: configGroupView.enableBackground
                            itemData: modelData
                            index: model.index
                            autoSave: configGroupView.autoSave
                            useCustomTranslate: configGroupView.useCustomTranslate
                            saveHandler: configGroupView.saveHandler
                            openExternalHandler: configGroupView.openExternalHandler
                        }

                    }

                }

            }

        }

    }

}
